@@ -1,5 +1,6 @@
 from rest_framework.decorators import api_view, permission_classes
 from rest_framework.permissions import IsAuthenticated
+from rest_framework.request import Request
 from rest_framework.response import Response
 
 from rest_registration.decorators import api_view_serializer_class_getter
@@ -10,7 +11,7 @@ from rest_registration.settings import registration_settings
     lambda: registration_settings.PROFILE_SERIALIZER_CLASS)
 @api_view(['GET', 'POST', 'PUT', 'PATCH'])
 @permission_classes([IsAuthenticated])
-def profile(request):
+def profile(request: Request) -> Response:
     '''
     Get or set user profile.
     '''
