@@ -1,8 +1,20 @@
-from typing import TYPE_CHECKING, Any, Dict, Iterable, List, Tuple, Union
+from typing import (
+    TYPE_CHECKING,
+    Any,
+    Callable,
+    Dict,
+    Iterable,
+    List,
+    Tuple,
+    TypeVar,
+    Union
+)
 
 from django.contrib import auth
 from django.contrib.auth import get_user_model
 from django.core.exceptions import ValidationError
+from django.db.models.base import Model
+from django.db.models.query import QuerySet
 from django.http import Http404
 from django.shortcuts import get_object_or_404 as _get_object_or_404
 
@@ -10,7 +22,15 @@ from rest_registration.exceptions import UserNotFound
 from rest_registration.settings import registration_settings
 from rest_registration.utils.common import set_or_none
 
-_RAISE_EXCEPTION = object()
+try:
+    from typing import Literal  # type: ignore
+except ImportError:
+    from typing_extensions import Literal
+
+
+_DefaultT = TypeVar('_DefaultT')
+_T = TypeVar('_T')
+_ModelT = TypeVar('_ModelT', bound=Model)
 
 if TYPE_CHECKING:
     from typing import Optional
@@ -20,27 +40,18 @@ if TYPE_CHECKING:
     UserField = Union['Field', 'ForeignObjectRel']
 
 
-def get_user_by_login_or_none(login, require_verified=False):
-    user = None
-    for login_field_name in get_user_login_field_names():
-        user = get_user_by_lookup_dict(
-            {login_field_name: login},
-            default=None, require_verified=require_verified)
-        if user:
-            break
-
-    return user
+_RAISE_EXCEPTION = object()
 
 
 def authenticate_by_login_data(
-        data: Dict[str, Any], **kwargs) -> 'AbstractBaseUser':
+        data: Dict[str, Any], **kwargs: Any) -> 'AbstractBaseUser':
     serializer = kwargs.get('serializer')
     if serializer:
         # TODO: Issue #114 - remove code supporting deprecated behavior
         get_authenticated_user = getattr(
             serializer, 'get_authenticated_user', None)
         if callable(get_authenticated_user):
-            user = get_authenticated_user()
+            user = get_authenticated_user()  # type: Optional[AbstractBaseUser]
             if not user:
                 raise UserNotFound()
             return user
@@ -74,18 +85,20 @@ def authenticate_by_login_data(
     raise UserNotFound()
 
 
-def get_user_login_field_names():
+def get_user_login_field_names() -> List[str]:
     user_class = get_user_model()
     return get_user_setting('LOGIN_FIELDS') or [user_class.USERNAME_FIELD]
 
 
-def get_user_verification_id(user):
+def get_user_verification_id(user: 'AbstractBaseUser') -> Any:
     verification_id_field = get_user_setting('VERIFICATION_ID_FIELD')
     return getattr(user, verification_id_field)
 
 
 def get_user_by_verification_id(
-        user_verification_id, default=_RAISE_EXCEPTION, require_verified=True):
+        user_verification_id: Any,
+        default: Union[_DefaultT, Literal[_RAISE_EXCEPTION]] = _RAISE_EXCEPTION,
+        require_verified: bool = True) -> Union['AbstractBaseUser', _DefaultT]:
     verification_id_field = get_user_setting('VERIFICATION_ID_FIELD')
     return get_user_by_lookup_dict({
         verification_id_field: user_verification_id},
@@ -94,7 +107,7 @@ def get_user_by_verification_id(
 
 
 def find_user_by_by_send_reset_password_link_data(
-        data: Dict[str, Any], **kwargs) -> 'AbstractBaseUser':
+        data: Dict[str, Any], **kwargs: Any) -> 'AbstractBaseUser':
     """
     Return user if matching given criteria (login fields / e-mail).
     Return ``None`` otherwise.
@@ -104,7 +117,7 @@ def find_user_by_by_send_reset_password_link_data(
         # TODO: Issue #114 - remove code supporting deprecated behavior
         get_user_or_none = getattr(serializer, 'get_user_or_none', None)
         if callable(get_user_or_none):
-            user = get_user_or_none()
+            user = get_user_or_none()  # type: Optional[AbstractBaseUser]
             if not user:
                 raise UserNotFound()
             return user
@@ -125,7 +138,7 @@ def find_user_by_by_send_reset_password_link_data(
     raise UserNotFound()
 
 
-def user_with_email_exists(email):
+def user_with_email_exists(email: str) -> bool:
     user_class = get_user_model()
     email_field_name = get_user_email_field_name()
     if not email_field_name:
@@ -134,18 +147,21 @@ def user_with_email_exists(email):
     return queryset.exists()
 
 
-def is_user_email_field_unique():
+def is_user_email_field_unique() -> bool:
     email_field_name = get_user_email_field_name()
     email_field = get_user_field_obj(email_field_name)
     return is_model_field_unique(email_field)
 
 
-def get_user_email_field_name():
-    return get_user_setting('EMAIL_FIELD')
+def get_user_email_field_name() -> str:
+    email = get_user_setting('EMAIL_FIELD')  # type: str
+    return email
 
 
 def get_user_by_lookup_dict(
-        lookup_dict, default=_RAISE_EXCEPTION, require_verified=True):
+        lookup_dict: Dict[str, Any],
+        default: Union[_DefaultT, Literal[_RAISE_EXCEPTION]] = _RAISE_EXCEPTION,
+        require_verified: bool = True) -> Union['AbstractBaseUser', _DefaultT]:
     verification_enabled = registration_settings.REGISTER_VERIFICATION_ENABLED
     verification_flag_field = get_user_setting('VERIFICATION_FLAG_FIELD')
     user_class = get_user_model()
@@ -154,7 +170,8 @@ def get_user_by_lookup_dict(
     if require_verified and verification_enabled and verification_flag_field:
         kwargs[verification_flag_field] = True
     try:
-        user = get_object_or_404(user_class.objects.all(), **kwargs)
+        queryset = user_class.objects.all()  # type: QuerySet[AbstractBaseUser]
+        user = get_object_or_404(queryset, **kwargs)
     except Http404:
         if default is _RAISE_EXCEPTION:
             raise UserNotFound() from None
@@ -163,12 +180,12 @@ def get_user_by_lookup_dict(
         return user
 
 
-def get_user_field_obj(name):
+def get_user_field_obj(name: str) -> 'UserField':
     user_class = get_user_model()
     return user_class._meta.get_field(name)  # pylint: disable=protected-access
 
 
-def get_user_setting(name):
+def get_user_setting(name: str) -> Any:
     setting_name = 'USER_{name}'.format(name=name)
     user_class = get_user_model()
     placeholder = object()
@@ -191,9 +208,10 @@ def build_initial_user(data: Dict[str, Any]) -> 'AbstractBaseUser':
 
 
 def get_user_field_names(
-        allow_primary_key: bool = True, non_editable: bool = False):
+        allow_primary_key: bool = True,
+        non_editable: bool = False) -> Tuple[str, ...]:
 
-    def not_in_seq(names):
+    def not_in_seq(names: Iterable[str]) -> Callable[[str], bool]:
         return lambda name: name not in names
 
     user_class = get_user_model()
@@ -223,9 +241,9 @@ def get_user_field_names(
     if non_editable:
         field_names = filter(not_in_seq(editable_field_names), field_names)
 
-    field_names = tuple(field_names)
+    field_names_tuple = tuple(field_names)
 
-    return field_names
+    return field_names_tuple
 
 
 def get_user_public_field_names(
@@ -311,11 +329,16 @@ def _get_user_default_fields() -> List['UserField']:
     return default_field_names
 
 
-def is_model_field_unique(field):
-    return field.unique or field.primary_key
+def is_model_field_unique(field: 'UserField') -> bool:
+    f_uniq = getattr(field, 'unique', False)  # type: bool
+    f_pkey = getattr(field, 'primary_key', False)  # type: bool
+    return f_uniq or f_pkey
 
 
-def get_object_or_404(queryset, *filter_args, **filter_kwargs):
+def get_object_or_404(
+        queryset: 'QuerySet[_ModelT]',
+        *filter_args: Any,
+        **filter_kwargs: Any) -> _ModelT:
     """
     Same as Django's standard shortcut, but make sure to also raise 404
     if the filter_kwargs don't match the required types.
